diff -aur x264-snapshot-20070711-2245/configure x264-fixed/configure
--- x264-snapshot-20070711-2245/configure	2007-07-11 13:45:03.000000000 -0700
+++ x264-fixed/configure	2007-07-11 16:43:37.000000000 -0700
@@ -19,6 +19,7 @@
 echo "  --extra-asflags=EASFLAGS add EASFLAGS to ASFLAGS"
 echo "  --extra-cflags=ECFLAGS   add ECFLAGS to CFLAGS"
 echo "  --extra-ldflags=ELDFLAGS add ELDFLAGS to LDFLAGS"
+echo "  --target=TARGETSYS       target for cross-compile (e.g. i386-mingw32)"
 echo ""
 exit 1
 fi
@@ -64,6 +65,8 @@
 shared="no"
 
 CC="${CC-gcc}"
+AR="ar"
+RANLIB="ranlib"
 CFLAGS="$CFLAGS -Wall -I."
 LDFLAGS="$LDFLAGS"
 HAVE_GETOPT_LONG=1
@@ -85,7 +88,103 @@
   exit 1
 fi
 
-MACHINE="$(./config.guess)"
+# parse options
+
+for opt do
+    optarg="${opt#*=}"
+    case "$opt" in
+        --prefix=*)
+            prefix="$optarg"
+            ;;
+        --exec-prefix=*)
+            exec_prefix="$optarg"
+            ;;
+        --bindir=*)
+            bindir="$optarg"
+            ;;
+        --libdir=*)
+            libdir="$optarg"
+            ;;
+        --includedir=*)
+            includedir="$optarg"
+            ;;
+        --enable-avis-input)
+            avis_input="yes"
+            ;;
+        --disable-avis-input)
+            avis_input="no"
+            ;;
+        --enable-mp4-output)
+            mp4_output="yes"
+            ;;
+        --disable-mp4-output)
+            mp4_output="no"
+            ;;
+        --extra-asflags=*)
+            ASFLAGS="$ASFLAGS ${opt#--extra-asflags=}"
+            ;;
+        --extra-cflags=*)
+            CFLAGS="$CFLAGS ${opt#--extra-cflags=}"
+            ;;
+        --extra-ldflags=*)
+            LDFLAGS="$LDFLAGS ${opt#--extra-ldflags=}"
+            ;;
+        --enable-pthread)
+            pthread="auto" # can't skip detection, since it differs by OS
+            ;;
+        --disable-pthread)
+            pthread="no"
+            ;;
+        --enable-debug)
+            debug="yes"
+            ;;
+        --enable-gprof)
+            CFLAGS="$CFLAGS -pg"
+            LDFLAGS="$LDFLAGS -pg"
+            gprof="yes"
+            ;;
+        --enable-pic)
+            pic="yes"
+            ;;
+        --enable-gtk)
+            gtk="yes"
+            ;;
+        --disable-gtk)
+            gtk="no"
+            ;;
+        --enable-shared)
+            shared="yes"
+            ;;
+        --enable-visualize)
+            LDFLAGS="$LDFLAGS -L/usr/X11R6/lib -lX11"
+            CFLAGS="$CFLAGS -DVISUALIZE=1"
+            vis="yes"
+            ;;
+        --target=*)
+            target="$optarg"
+            ;;
+        --cache-file=*)
+            cachename="$optarg"
+            ;;
+        --host=*)
+            buildhost="$optarg"
+            ;;
+        --build=*)
+            buildname="$optarg"
+            ;;
+        *)
+            echo "Unknown option $opt, ignored"
+            ;;
+    esac
+done
+
+if [ -z "${target}" ] ; then
+  MACHINE="$(./config.guess)"
+else
+  tsys="${target#*-}"
+  tarch="${target%%-*}"
+  MACHINE="${tarch}-unknown-${tsys}-unknown"
+fi
 
 case "${MACHINE#*-*-}" in
   beos*)
@@ -202,6 +301,12 @@
     ;;
 esac
 
+if [ $shared = "yes" ] ; then
+  if [ $ARCH = "X86_64" -o $ARCH = "PPC" -o $ARCH = "ALPHA"  ] ; then
+    pic="yes"
+  fi
+fi
+
 # check requirements
 
 if [ $SYS = MACOSX -a $ARCH = X86 ]
@@ -233,87 +338,6 @@
 
 CFLAGS="$CFLAGS -DARCH_$ARCH -DSYS_$SYS"
 
-# parse options
-
-for opt do
-    optarg="${opt#*=}"
-    case "$opt" in
-        --prefix=*)
-            prefix="$optarg"
-            ;;
-        --exec-prefix=*)
-            exec_prefix="$optarg"
-            ;;
-        --bindir=*)
-            bindir="$optarg"
-            ;;
-        --libdir=*)
-            libdir="$optarg"
-            ;;
-        --includedir=*)
-            includedir="$optarg"
-            ;;
-        --enable-avis-input)
-            avis_input="yes"
-            ;;
-        --disable-avis-input)
-            avis_input="no"
-            ;;
-        --enable-mp4-output)
-            mp4_output="yes"
-            ;;
-        --disable-mp4-output)
-            mp4_output="no"
-            ;;
-        --extra-asflags=*)
-            ASFLAGS="$ASFLAGS ${opt#--extra-asflags=}"
-            ;;
-        --extra-cflags=*)
-            CFLAGS="$CFLAGS ${opt#--extra-cflags=}"
-            ;;
-        --extra-ldflags=*)
-            LDFLAGS="$LDFLAGS ${opt#--extra-ldflags=}"
-            ;;
-        --enable-pthread)
-            pthread="auto" # can't skip detection, since it differs by OS
-            ;;
-        --disable-pthread)
-            pthread="no"
-            ;;
-        --enable-debug)
-            debug="yes"
-            ;;
-        --enable-gprof)
-            CFLAGS="$CFLAGS -pg"
-            LDFLAGS="$LDFLAGS -pg"
-            gprof="yes"
-            ;;
-        --enable-pic)
-            pic="yes"
-            ;;
-        --enable-gtk)
-            gtk="yes"
-            ;;
-        --disable-gtk)
-            gtk="no"
-            ;;
-        --enable-shared)
-            shared="yes"
-            if [ $ARCH = "X86_64" -o $ARCH = "PPC" -o $ARCH = "ALPHA" ] ; then
-                pic="yes"
-            fi
-            ;;
-        --enable-visualize)
-            LDFLAGS="$LDFLAGS -L/usr/X11R6/lib -lX11"
-            CFLAGS="$CFLAGS -DVISUALIZE=1"
-            vis="yes"
-            ;;
-        *)
-            echo "Unknown option $opt, ignored"
-            ;;
-    esac
-done
-
 # autodetect options that weren't forced nor disabled
 
 libpthread=""
@@ -395,6 +419,10 @@
     echo "#define ftell ftello64" >> config.h
 fi
 
+if [ "$target" != "$host" ]; then
+  crosstoolsprefix="${target}-"
+fi
+
 # generate config files
 
 cat > config.mak << EOF
@@ -405,7 +433,7 @@
 includedir=$includedir
 ARCH=$ARCH
 SYS=$SYS
-CC=$CC
+CC=$crosstoolsprefix$CC
 CFLAGS=$CFLAGS
 ALTIVECFLAGS=$ALTIVECFLAGS
 LDFLAGS=$LDFLAGS
@@ -417,6 +445,8 @@
 HAVE_GETOPT_LONG=$HAVE_GETOPT_LONG
 DEVNULL=$DEVNULL
 ECHON=$ECHON
+RANLIB=$crosstoolsprefix$RANLIB
+AR=$crosstoolsprefix$AR
 EOF
 
 $ECHON 'CONFIGURE_ARGS=' >> config.mak
diff -aur x264-snapshot-20070711-2245/Makefile x264-fixed/Makefile
--- x264-snapshot-20070711-2245/Makefile	2007-07-11 13:45:03.000000000 -0700
+++ x264-fixed/Makefile	2007-07-11 16:41:25.000000000 -0700
@@ -73,8 +73,8 @@
 default: $(DEP) x264$(EXE)
 
 libx264.a: .depend $(OBJS) $(OBJASM)
-	ar rc libx264.a $(OBJS) $(OBJASM)
-	ranlib libx264.a
+	$(AR) rc libx264.a $(OBJS) $(OBJASM)
+	$(RANLIB) libx264.a
 
 $(SONAME): .depend $(OBJS) $(OBJASM)
 	$(CC) -shared -o $@ $(OBJS) $(OBJASM) -Wl,-soname,$(SONAME) $(LDFLAGS)
@@ -146,14 +146,14 @@
 	rm -rf test/
 	$(MAKE) -C gtk distclean
 
-install: x264 $(SONAME)
+install: x264$(EXE) $(SONAME)
 	install -d $(DESTDIR)$(bindir) $(DESTDIR)$(includedir)
 	install -d $(DESTDIR)$(libdir) $(DESTDIR)$(libdir)/pkgconfig
 	install -m 644 x264.h $(DESTDIR)$(includedir)
 	install -m 644 libx264.a $(DESTDIR)$(libdir)
 	install -m 644 x264.pc $(DESTDIR)$(libdir)/pkgconfig
-	install x264 $(DESTDIR)$(bindir)
-	ranlib $(DESTDIR)$(libdir)/libx264.a
+	install x264$(EXE) $(DESTDIR)$(bindir)
+	$(RANLIB) $(DESTDIR)$(libdir)/libx264.a
 	$(if $(SONAME), ln -sf $(SONAME) $(DESTDIR)$(libdir)/libx264.so)
 	$(if $(SONAME), install -m 755 $(SONAME) $(DESTDIR)$(libdir))
 
